jaspr_icons library

a library that provides access to svg icons for use in jaspr apps.

Classes

FluentIcons
A collection of Microsoft Fluent UI System icons (24px variants).
Icon
Render an svg icon from a structured IconData object.
IconData
a helper class that stores the data for an svg icon
LucidIcons
A collection of Lucide icons.
MaterialIcons
A collection of Material icons.
TablerIcons
A collection of Tabler icons.

Enums

StrokeLineCap
stroke-linecap options
StrokeLineJoin
stroke-linejoin options